@@ -97,37 +97,41 @@ def find_blas():
 	system_include_paths = []
 
 	# sys.stdout = open(os.devnull, "w")
-	_try_add_from_command("numpy.distutils.system_info.get_info('mkl')['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas_mkl')['library_dirs']", candidate_paths)
-	_try_add_from_command("np.__config__.system_info.blas_mkl_info['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.mkl_info['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.blas_mkl_info['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('mkl')['include_dirs']", mkl_include_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas_mkl')['include_dirs']", mkl_include_paths)
-	_try_add_from_command("np.__config__.system_info.blas_mkl_info['include_dirs']", mkl_include_paths)
-	_try_add_from_command("scipy.__config__.mkl_info['include_dirs']", mkl_include_paths)
-	_try_add_from_command("scipy.__config__.blas_mkl_info['include_dirs']", mkl_include_paths)
+	import io
+	from contextlib import redirect_stdout
+	_ = io.StringIO()
+	with redirect_stdout(_):
+		_try_add_from_command("numpy.distutils.system_info.get_info('mkl')['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas_mkl')['library_dirs']", candidate_paths)
+		_try_add_from_command("np.__config__.system_info.blas_mkl_info['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.mkl_info['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.blas_mkl_info['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('mkl')['include_dirs']", mkl_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas_mkl')['include_dirs']", mkl_include_paths)
+		_try_add_from_command("np.__config__.system_info.blas_mkl_info['include_dirs']", mkl_include_paths)
+		_try_add_from_command("scipy.__config__.mkl_info['include_dirs']", mkl_include_paths)
+		_try_add_from_command("scipy.__config__.blas_mkl_info['include_dirs']", mkl_include_paths)
 
-	_try_add_from_command("numpy.distutils.system_info.get_info('openblas')['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.openblas_info['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.openblas_lapack_info['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('openblas')['include_dirs']", openblas_include_paths)
-	_try_add_from_command("scipy.__config__.openblas_info['include_dirs']", openblas_include_paths)
-	_try_add_from_command("scipy.__config__.openblas_lapack_info['include_dirs']", openblas_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('openblas')['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.openblas_info['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.openblas_lapack_info['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('openblas')['include_dirs']", openblas_include_paths)
+		_try_add_from_command("scipy.__config__.openblas_info['include_dirs']", openblas_include_paths)
+		_try_add_from_command("scipy.__config__.openblas_lapack_info['include_dirs']", openblas_include_paths)
 
-	_try_add_from_command("numpy.distutils.system_info.get_info('atlas')['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('atlas_blas')['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.atlas_info['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('atlas')['include_dirs']", atlas_include_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('atlas_blas')['include_dirs']", atlas_include_paths)
-	_try_add_from_command("scipy.__config__.atlas_info['include_dirs']", atlas_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('atlas')['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('atlas_blas')['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.atlas_info['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('atlas')['include_dirs']", atlas_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('atlas_blas')['include_dirs']", atlas_include_paths)
+		_try_add_from_command("scipy.__config__.atlas_info['include_dirs']", atlas_include_paths)
 
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas')['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas_opt')['library_dirs']", candidate_paths)
-	_try_add_from_command("scipy.__config__.blas_opt_info['library_dirs']", candidate_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas')['include_dirs']", gsl_include_paths)
-	_try_add_from_command("numpy.distutils.system_info.get_info('blas_opt')['include_dirs']", gsl_include_paths)
-	_try_add_from_command("scipy.__config__.blas_opt_info['include_dirs']", gsl_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas')['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas_opt')['library_dirs']", candidate_paths)
+		_try_add_from_command("scipy.__config__.blas_opt_info['library_dirs']", candidate_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas')['include_dirs']", gsl_include_paths)
+		_try_add_from_command("numpy.distutils.system_info.get_info('blas_opt')['include_dirs']", gsl_include_paths)
+		_try_add_from_command("scipy.__config__.blas_opt_info['include_dirs']", gsl_include_paths)
 	# sys.stdout = sys.__stdout__
 
 	python_fold = sys.prefix
@@ -316,6 +320,38 @@ def find_blas():
 
 	candidate_paths += paths_pep518
 
+	## Try getting MKL from pip too
+	try:
+		import pip
+		import io
+		from contextlib import redirect_stdout
+
+		try:
+			pip_outp = io.StringIO()
+			with redirect_stdout(pip_outp):
+				pip.main(['show', '-f', 'mkl'])
+		except:
+			pip_outp = io.StringIO()
+			with redirect_stdout(pip_outp):
+				os.system("pip show -f mkl")
+
+		pip_outp = pip_outp.getvalue()
+		pip_outp = pip_outp.split("\n")
+		for ln in pip_outp:
+			if bool(re.search(r"^Location", ln)):
+				files_root = re.sub(r"^Location:\s+", "", ln)
+				files_root = files_root.rstrip()
+				break
+
+		for ln in pip_outp:
+			if bool(re.search(r"mkl_rt\.[solibdyaSOLIBDYA]+$", ln)):
+				candidate_paths.append(
+					os.path.join(files_root, re.sub(r"^\s*(.*)[/\\]+[lib]*mkl_rt\.[solibdyaSOLIBDYA]+$", r"\1", ln))
+				)
+
+	except:
+		pass
+
 	## Discard duplicated paths, but keep the order
 	search_paths = _deduplicate_paths(candidate_paths)
 
